You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/01 08:27:13 UTC

svn commit: r1208981 [4/24] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mail...

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/HttpHeaderResult.java Thu Dec  1 07:18:07 2011
@@ -29,11 +29,11 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.ServletActionContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/PlainTextResult.java Thu Dec  1 07:18:07 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletResponse;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletActionRedirectResult.java Thu Dec  1 07:18:07 2011
@@ -27,10 +27,8 @@ import java.util.List;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionExceptionHandler;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.reflection.ReflectionExceptionHandler;
 
 /**
  * <!-- START SNIPPET: description -->
@@ -163,7 +161,7 @@ public class ServletActionRedirectResult
     }
 
     /**
-     * @see com.opensymphony.xwork2.Result#execute(com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.xwork2.Result#execute(org.apache.struts2.xwork2.ActionInvocation)
      */
     public void execute(ActionInvocation invocation) throws Exception
     {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletDispatcherResult.java Thu Dec  1 07:18:07 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsStatics;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ServletRedirectResult.java Thu Dec  1 07:18:07 2011
@@ -21,14 +21,14 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionExceptionHandler;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionExceptionHandler;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StreamResult.java Thu Dec  1 07:18:07 2011
@@ -26,10 +26,10 @@ import java.io.OutputStream;
 
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: description -->
@@ -215,7 +215,7 @@ public class StreamResult extends Struts
     }
 
     /**
-     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.dispatcher.StrutsResultSupport#doExecute(java.lang.String, org.apache.struts2.xwork2.ActionInvocation)
      */
     protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsRequestWrapper.java Thu Dec  1 07:18:07 2011
@@ -24,8 +24,8 @@ package org.apache.struts2.dispatcher;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java Thu Dec  1 07:18:07 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.views.JspSupportServlet;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/CompositeActionMapper.java Thu Dec  1 07:18:07 2011
@@ -28,11 +28,11 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapper.java Thu Dec  1 07:18:07 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.dispatcher.mapper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.RequestUtils;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/PrefixBasedActionMapper.java Thu Dec  1 07:18:07 2011
@@ -1,8 +1,8 @@
 package org.apache.struts2.dispatcher.mapper;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/Restful2ActionMapper.java Thu Dec  1 07:18:07 2011
@@ -29,10 +29,10 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapper.java Thu Dec  1 07:18:07 2011
@@ -23,7 +23,6 @@ package org.apache.struts2.dispatcher.ma
 
 import java.net.URLDecoder;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.StringTokenizer;
 
@@ -31,9 +30,9 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.RequestUtils;
 
-import com.opensymphony.xwork2.config.ConfigurationManager;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.ConfigurationManager;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/JakartaMultiPartRequest.java Thu Dec  1 07:18:07 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.dispatcher.multipart;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.apache.commons.fileupload.RequestContext;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/multipart/MultiPartRequestWrapper.java Thu Dec  1 07:18:07 2011
@@ -34,8 +34,8 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.dispatcher.StrutsRequestWrapper;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/InitOperations.java Thu Dec  1 07:18:07 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2.dispatcher.ng;
 
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.dispatcher.StaticContentLoader;
 import org.apache.struts2.util.ClassLoaderUtils;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/ng/PrepareOperations.java Thu Dec  1 07:18:07 2011
@@ -31,11 +31,11 @@ import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.IOException;
 import java.util.HashMap;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxy.java Thu Dec  1 07:18:07 2011
@@ -23,11 +23,9 @@
 
 package org.apache.struts2.impl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.DefaultActionProxy;
-
-import java.util.Map;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.DefaultActionProxy;
 
 public class StrutsActionProxy extends DefaultActionProxy {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsActionProxyFactory.java Thu Dec  1 07:18:07 2011
@@ -23,11 +23,9 @@
 
 package org.apache.struts2.impl;
 
-import java.util.Map;
-
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.DefaultActionProxyFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.DefaultActionProxyFactory;
 
 public class StrutsActionProxyFactory extends DefaultActionProxyFactory {
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/impl/StrutsObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -23,12 +23,10 @@
 
 package org.apache.struts2.impl;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.InterceptorConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.InterceptorConfig;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CheckboxInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CheckboxInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CheckboxInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CheckboxInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
 
 import java.util.Map;
 import java.util.Set;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ClearSessionInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ClearSessionInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ClearSessionInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ClearSessionInterceptor.java Thu Dec  1 07:18:07 2011
@@ -23,11 +23,11 @@ package org.apache.struts2.interceptor;
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java Thu Dec  1 07:18:07 2011
@@ -24,17 +24,16 @@ package org.apache.struts2.interceptor;
 import java.util.*;
 
 import javax.servlet.http.Cookie;
-import javax.servlet.http.HttpServletRequest;
 
 import org.apache.struts2.ServletActionContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CreateSessionInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CreateSessionInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CreateSessionInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/CreateSessionInterceptor.java Thu Dec  1 07:18:07 2011
@@ -23,10 +23,10 @@ package org.apache.struts2.interceptor;
 
 import org.apache.struts2.ServletActionContext;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,23 +21,19 @@
 
 package org.apache.struts2.interceptor;
 
-import java.util.Collections;
 import java.util.Map;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.interceptor.MethodFilterInterceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.util.TokenHelper;
 import org.apache.struts2.ServletActionContext;
-import org.apache.struts2.dispatcher.Dispatcher;
-import org.apache.struts2.views.freemarker.FreemarkerManager;
 import org.apache.struts2.views.freemarker.FreemarkerResult;
 
 import javax.servlet.http.HttpSession;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/FileUploadInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/FileUploadInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/FileUploadInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/FileUploadInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,17 +21,17 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.PatternMatcher;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.PatternMatcher;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.dispatcher.multipart.MultiPartRequestWrapper;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MessageStoreInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MessageStoreInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MessageStoreInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MessageStoreInterceptor.java Thu Dec  1 07:18:07 2011
@@ -28,12 +28,12 @@ import java.util.Map;
 
 import org.apache.struts2.dispatcher.ServletRedirectResult;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MultiselectInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MultiselectInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MultiselectInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/MultiselectInterceptor.java Thu Dec  1 07:18:07 2011
@@ -26,8 +26,8 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
 
 
 /**
@@ -46,7 +46,7 @@ public class MultiselectInterceptor exte
      * @param actionInvocation ActionInvocation
      * @return the result of the action
      * @throws Exception if error
-     * @see com.opensymphony.xwork2.interceptor.Interceptor#intercept(com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.xwork2.interceptor.Interceptor#intercept(org.apache.struts2.xwork2.ActionInvocation)
      */
     public String intercept(ActionInvocation actionInvocation) throws Exception {
         Map parameters = actionInvocation.getInvocationContext().getParameters();

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/NoParameters.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/NoParameters.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/NoParameters.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/NoParameters.java Thu Dec  1 07:18:07 2011
@@ -29,5 +29,5 @@ package org.apache.struts2.interceptor;
  * security reasons wants to make sure that parameters cannot be set by malicious users.
  *
  */
-public interface NoParameters extends com.opensymphony.xwork2.interceptor.NoParameters {
+public interface NoParameters extends org.apache.struts2.xwork2.interceptor.NoParameters {
 }

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ProfilingActivationInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ProfilingActivationInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ProfilingActivationInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ProfilingActivationInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.profiling.UtilTimerStack;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.profiling.UtilTimerStack;
 
 import org.apache.struts2.StrutsConstants;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/RolesInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/RolesInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/RolesInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/RolesInterceptor.java Thu Dec  1 07:18:07 2011
@@ -29,8 +29,8 @@ import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
 
 import org.apache.struts2.ServletActionContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ScopeInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ScopeInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ScopeInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ScopeInterceptor.java Thu Dec  1 07:18:07 2011
@@ -29,14 +29,14 @@ import org.apache.struts2.ServletActionC
 import org.apache.struts2.StrutsException;
 import org.apache.struts2.dispatcher.SessionMap;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.interceptor.PreResultListener;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.interceptor.PreResultListener;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ServletConfigInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ServletConfigInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ServletConfigInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/ServletConfigInterceptor.java Thu Dec  1 07:18:07 2011
@@ -31,9 +31,9 @@ import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.servlet.interceptor.ServletPrincipalProxy;
 import org.apache.struts2.util.ServletContextAware;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.ConversionErrorInterceptor;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.ConversionErrorInterceptor;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**
@@ -67,7 +67,7 @@ import com.opensymphony.xwork2.util.Valu
  * <!-- END SNIPPET: example -->
  * </pre>
  *
- * @see com.opensymphony.xwork2.ActionContext#getConversionErrors()
+ * @see org.apache.struts2.xwork2.ActionContext#getConversionErrors()
  * @see ConversionErrorInterceptor
  */
 public class StrutsConversionErrorInterceptor extends ConversionErrorInterceptor {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.interceptor.MethodFilterInterceptor;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
 import org.apache.struts2.ServletActionContext;
 import org.apache.struts2.util.TokenHelper;
 
@@ -121,7 +121,7 @@ public class TokenInterceptor extends Me
     public static final String INVALID_TOKEN_CODE = "invalid.token";
 
     /**
-     * @see com.opensymphony.xwork2.interceptor.MethodFilterInterceptor#doIntercept(com.opensymphony.xwork2.ActionInvocation)
+     * @see org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor#doIntercept(org.apache.struts2.xwork2.ActionInvocation)
      */
     protected String doIntercept(ActionInvocation invocation) throws Exception {
         if (log.isDebugEnabled()) {

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptor.java Thu Dec  1 07:18:07 2011
@@ -30,10 +30,10 @@ import org.apache.struts2.ServletActionC
 import org.apache.struts2.util.InvocationSessionStore;
 import org.apache.struts2.util.TokenHelper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/DebuggingInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/DebuggingInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/DebuggingInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/DebuggingInterceptor.java Thu Dec  1 07:18:07 2011
@@ -44,15 +44,15 @@ import org.apache.struts2.dispatcher.Fil
 import org.apache.struts2.views.freemarker.FreemarkerManager;
 import org.apache.struts2.views.freemarker.FreemarkerResult;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.interceptor.PreResultListener;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.interceptor.PreResultListener;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/ObjectToHTMLWriter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/ObjectToHTMLWriter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/ObjectToHTMLWriter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/interceptor/debugging/ObjectToHTMLWriter.java Thu Dec  1 07:18:07 2011
@@ -29,8 +29,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 /**
  * Writes an object as a table, where each field can be expanded if it is an Object/Collection/Array

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/InvocationSessionStore.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/InvocationSessionStore.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/InvocationSessionStore.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/InvocationSessionStore.java Thu Dec  1 07:18:07 2011
@@ -25,9 +25,9 @@ import java.io.Serializable;
 import java.util.HashMap;
 import java.util.Map;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/IteratorGenerator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/IteratorGenerator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/IteratorGenerator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/IteratorGenerator.java Thu Dec  1 07:18:07 2011
@@ -26,9 +26,9 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/MergeIteratorFilter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/MergeIteratorFilter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/MergeIteratorFilter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/MergeIteratorFilter.java Thu Dec  1 07:18:07 2011
@@ -25,7 +25,7 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/RegexPatternMatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/RegexPatternMatcher.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/RegexPatternMatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/RegexPatternMatcher.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.util;
 
-import com.opensymphony.xwork2.util.PatternMatcher;
+import org.apache.struts2.xwork2.util.PatternMatcher;
 import org.apache.commons.lang.StringUtils;
 
 import java.util.HashMap;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SortIteratorFilter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SortIteratorFilter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SortIteratorFilter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SortIteratorFilter.java Thu Dec  1 07:18:07 2011
@@ -27,8 +27,8 @@ import java.util.Comparator;
 import java.util.Iterator;
 import java.util.List;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTestCaseHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTestCaseHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTestCaseHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTestCaseHelper.java Thu Dec  1 07:18:07 2011
@@ -26,10 +26,10 @@ import java.util.Map;
 
 import org.apache.struts2.dispatcher.Dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
 
 import javax.servlet.ServletContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTypeConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTypeConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTypeConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsTypeConverter.java Thu Dec  1 07:18:07 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.util;
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.conversion.impl.DefaultTypeConverter;
+import org.apache.struts2.xwork2.conversion.impl.DefaultTypeConverter;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/StrutsUtil.java Thu Dec  1 07:18:07 2011
@@ -40,17 +40,15 @@ import javax.servlet.http.HttpServletReq
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpServletResponseWrapper;
 
-import org.apache.commons.lang.StringEscapeUtils;
-
 import org.apache.struts2.views.jsp.ui.OgnlTool;
 import org.apache.struts2.views.util.UrlHelper;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SubsetIteratorFilter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SubsetIteratorFilter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SubsetIteratorFilter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/SubsetIteratorFilter.java Thu Dec  1 07:18:07 2011
@@ -25,9 +25,9 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TextProviderHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TextProviderHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TextProviderHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TextProviderHelper.java Thu Dec  1 07:18:07 2011
@@ -21,10 +21,10 @@
 
 package org.apache.struts2.util;
 
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collections;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TokenHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TokenHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TokenHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/TokenHelper.java Thu Dec  1 07:18:07 2011
@@ -25,10 +25,10 @@ import java.math.BigInteger;
 import java.util.Map;
 import java.util.Random;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * TokenHelper

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/VelocityStrutsUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/VelocityStrutsUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/VelocityStrutsUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/util/VelocityStrutsUtil.java Thu Dec  1 07:18:07 2011
@@ -33,7 +33,7 @@ import org.apache.velocity.exception.Met
 import org.apache.velocity.exception.ParseErrorException;
 import org.apache.velocity.exception.ResourceNotFoundException;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/DefaultTagLibrary.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/DefaultTagLibrary.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/DefaultTagLibrary.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/DefaultTagLibrary.java Thu Dec  1 07:18:07 2011
@@ -65,7 +65,7 @@ import org.apache.struts2.views.velocity
 import org.apache.struts2.views.velocity.components.URLDirective;
 import org.apache.struts2.views.velocity.components.UpDownSelectDirective;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * The default Struts tag library

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/TagLibrary.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/TagLibrary.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/TagLibrary.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/TagLibrary.java Thu Dec  1 07:18:07 2011
@@ -26,7 +26,7 @@ import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * Provides Velocity and Freemarker implementation classes for a tag library

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerManager.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerManager.java Thu Dec  1 07:18:07 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2.views.freemarker;
 
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import freemarker.cache.*;
 import freemarker.ext.jsp.TaglibFactory;
 import freemarker.ext.servlet.HttpRequestHashModel;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/FreemarkerResult.java Thu Dec  1 07:18:07 2011
@@ -21,11 +21,11 @@
 
 package org.apache.struts2.views.freemarker;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.LocaleProvider;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.LocaleProvider;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
 import freemarker.template.Configuration;
 import freemarker.template.ObjectWrapper;
 import freemarker.template.Template;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/ScopesHashModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/ScopesHashModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/ScopesHashModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/ScopesHashModel.java Thu Dec  1 07:18:07 2011
@@ -25,7 +25,7 @@ import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 import freemarker.template.ObjectWrapper;
 import freemarker.template.SimpleHash;

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/StrutsClassTemplateLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/StrutsClassTemplateLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/StrutsClassTemplateLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/StrutsClassTemplateLoader.java Thu Dec  1 07:18:07 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.views.freemar
 
 import java.net.URL;
 
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
 
 import freemarker.cache.URLTemplateLoader;
 

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxListModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxListModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxListModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxListModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.CheckboxList;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see CheckboxList

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/CheckboxModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Checkbox;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Checkbox

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComboBoxModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComboBoxModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComboBoxModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComboBoxModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.ComboBox;
 import org.apache.struts2.components.Component;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ComboBox

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComponentModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComponentModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComponentModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ComponentModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.GenericUIBean;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see ComponentModel

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DateModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DateModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DateModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DateModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Date;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <code>DateModel</code>

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DivModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DivModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DivModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DivModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Div;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Div

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DoubleSelectModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DoubleSelectModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DoubleSelectModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/DoubleSelectModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.DoubleSelect;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see DoubleSelect

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseIfModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseIfModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseIfModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseIfModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.ElseIf;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @version $Date$ $Id$

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/ElseModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Else;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  *

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FieldErrorModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FieldErrorModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FieldErrorModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FieldErrorModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.FieldError;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see FieldError

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FileModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FileModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FileModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FileModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.File;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see File

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FormModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FormModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FormModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/FormModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Form;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Form

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HeadModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HeadModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HeadModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HeadModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Head;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Head

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HiddenModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HiddenModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HiddenModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/HiddenModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.Hidden;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Hidden

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/I18nModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/I18nModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/I18nModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/I18nModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.I18n;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see I18n

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/IfModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/IfModel.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/IfModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/views/freemarker/tags/IfModel.java Thu Dec  1 07:18:07 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.components.If;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @version $Date$ $Id$
--- struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/StrutsResultSupport.java Thu Dec  1 07:18:07 2011
@@ -26,11 +26,11 @@ import java.net.URLEncoder;
 
 import org.apache.struts2.StrutsStatics;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**
@@ -43,7 +43,7 @@ import com.opensymphony.xwork2.util.logg
  * <ul>
  * <li>location - the location to go to after execution (could be a jsp page or another action).
  * It can be parsed as per the rules definied in the
- * {@link TextParseUtil#translateVariables(java.lang.String, com.opensymphony.xwork2.util.ValueStack) translateVariables}
+ * {@link TextParseUtil#translateVariables(java.lang.String, org.apache.struts2.xwork2.util.ValueStack) translateVariables}
  * method</li>
  * <li>parse - true by default. If set to false, the location param will not be parsed for expressions</li>
  * <li>encode - false by default. If set to false, the location param will not be url encoded. This only have effect when parse is true</li>
@@ -95,11 +95,11 @@ import com.opensymphony.xwork2.util.logg
  *      &lt;result-type name="myresult" class="com.foo.MyResult" /&gt;
  *  &lt;/result-types&gt;</pre>
  * <p/>
  * Please see the {@link com.opensymphony.xwork2.Result} class for more info on Results in general.
  *
  * <!-- END SNIPPET: example -->
  *
- * @see com.opensymphony.xwork2.Result
+ * @see org.apache.struts2.xwork2.Result
  */
 public abstract class StrutsResultSupport implements Result, StrutsStatics {
 
@@ -95,11 +95,11 @@ import com.opensymphony.xwork2.util.logg
  *  &lt;/result-types&gt;</pre>
  * <p/>
- * Please see the {@link com.opensymphony.xwork2.Result} class for more info on Results in general.
+ * Please see the {@link org.apache.struts2.xwork2.Result} class for more info on Results in general.
  *
  * <!-- END SNIPPET: example -->

Modified: struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/core/src/main/java/org/apache/struts2/dispatcher/VelocityResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================